@@ -23,5 +23,6 @@ c              For Lund related block common
       external ludataC
       external luedatC
       external luhdatC
-      external cblkSpeical
+      external cblkSpecial
+
 
