@@ -1,5 +1,6 @@
       subroutine xBgRun
       implicit none
+#include  "Zmaxdef.h"
 #include "Zmanagerp.h"
 #include "Ztrack.h"
 #include "Ztrackv.h"
@@ -8,10 +9,14 @@
 #include "Zobs.h"
 #include "Zobsp.h"
 #include "Zobsv.h"
+#include  "Zstackv.h"
       include "Zprivate.f"
       include "Zprivate2.f"
 
-      save rspec, lossrspec, lossrspec2, respec
+
+
+            
+      save rspec, lossrspec, arspec, respec
       save rzspec,  zfspec, rtspec1, rtspec2, retspec1, retspec2
       save rezspec,  rzfspec, rfspec, efspec, refspec
 
@@ -36,6 +41,7 @@ c                           3 ==> reached at inner boundery.
 
       real*8 r, Eloss, rinmu, cosang
       real*8 dedt, rho, dist, disto
+      real*8 aa
       real*8 wx, wy, wz, temp
       real   za
       real  de, Ek, f, molu
@@ -116,12 +122,26 @@ c
      *         "dEdxLat", "GeV/(g/cm^2)", .true., power2(j),
      *         "r", "m.u")
             enddo
-c                e+mu in the central region
-c            call kwhisti( lossrspec2(i), 0., 1.0, 20, b'00000')
          enddo   
       endif
 
 
+      if(tkarspec) then
+         do i = 1, ansites
+            do j = 1, 3           ! g,e,mu
+               call kwhisti2(arspec(j, i),
+     *              0.,  45.0, 8,     b'00010',
+     *              rmin, bin, nrbin,  b'00011' )
+cc             call kwhiststep2(arspec(j, i), 2)
+               call kwhistai2(arspec(j,i), 
+     *         "Lateral Dist. of "//ptcl(j)//" at  diff. azimuth",
+     *         "ar", "ptcls", .true.,  power(j), 
+     *         "azimuth", "deg", "r", "m.u")
+            enddo
+         enddo
+      endif
+         
+
 c
       if(tkrespec) then
          do i = 1, ansites
@@ -394,11 +414,18 @@ c
             do j = 1, 3
                call kwhistc(lossrspec(j,i))
             enddo
-c            call kwhistc(lossrspec2(i))
          enddo
       endif
 
 
+      if(tkarspec) then
+         do i = 1, ansites
+            do j = 1, 3
+               call kwhistc2(arspec(j,i))
+            enddo
+         enddo
+      endif
+
       if(tkrespec) then
          do i = 1, ansites
             do j = 1, 3
@@ -497,7 +524,8 @@ c
 c     **************************
       obstimes = obstimes + 1.d0
       if( mod(obstimes, 100000.d0) .eq. 0. ) then 
-         write(0, *) ' obstime=', obstimes, ' ptclE=',aTrack.p.fm.p(4)
+         write(0, *) ' obstimes=', obstimes, ' ptclE=',aTrack.p.fm.p(4),
+     *   ' maxE remain=',Stack(1).p.fm.p(4)
       endif
 c     ***************
       code = aTrack.p.code
@@ -528,7 +556,7 @@ c     ***************
                sr = rinmu
 
                if(  recxy ) then
-                  write(*,'("p ", 4i4, g12.3, 3g12.3,  3f10.6 )')
+                  write(*,'("p ", 4i4, 1pE11.3, 3E11.3, 0p3f10.6 )')
      *                 ldep,  code,  aTrack.p.subcode,
      *                 aTrack.p.charge, aTrack.p.fm.e, 
      *                 aTrack.pos.xyz.x/molu,
@@ -537,7 +565,7 @@ c     ***************
      *                 -sngl(aTrack.vec.w.r(1)),
      *                 -sngl(aTrack.vec.w.r(2)), wz
                else
-                  write(*,'("p ", 4i4, g12.3, 2g12.3, f10.6 )')
+                  write(*,'("p ", 4i4, 1pE11.3, 2E11.3, 0pf10.6 )')
      *                 ldep,  code,  aTrack.p.subcode,
      *                 aTrack.p.charge, aTrack.p.fm.e,
      *                 sr,
@@ -581,8 +609,9 @@ c                     see if this is > K.E
             Eloss = Eloss*10.       !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          endif
+      endif
 c            ------------------
-               
+      if(id .eq. 2 .and. code .le. 3) then
 c          see if 'where' is specified for histogram
          do i = 1, ansites
             if( histdep(i) .eq. ldep )  then
@@ -591,7 +620,7 @@ c
                molu = ObsSites(ldep).mu
                rinmu = r/molu
                sr = rinmu
-               if( tklat .and. code .le. 3) then
+               if( tklat ) then
 c                    lateral
                   call kwhist(rspec(code, i), sr, 1.0 )
                endif
@@ -635,7 +664,7 @@ cc                        tempr = rbin(ic)/ObsSites(j).mu
 cc                     endif
 c                       by   all charged particles
                      call kwhist(lossrspec(3,i), tempr, de)
-c                     call kwhist(lossrspec2(i), tempr, de)
+
                      if( aTrack.p.code .eq.  kelec ) then
 c                          by electrons
                         call kwhist(lossrspec(1,i), tempr, de)
@@ -647,8 +676,17 @@ cc                  enddo
                endif          
 c                  end of eloss late
 
+               if(tkarspec) then
+c                    arspec
+                  aa=atan2(aTrack.pos.xyz.y,aTrack.pos.xyz.x)*
+     *             57.29577951308230 
+                  aa= mod(aa + 360.d0,   360.d0)
+                  if(aa .gt. 337.5d0) aa= aa-360.d0
+                  call kwhist2( arspec(code, i), sngl(aa), sr, 1.0)
+               endif
 
-               if( tkrespec .and. code .le. 3 ) then
+
+               if( tkrespec ) then
 c                  re spectrum
                   call kwhist2( respec(code, i), sr, Ek, 1.0)
                endif
@@ -690,31 +728,31 @@ c                  re spectrum
      *              sr, f, 1.0 )
                endif
 
-               if( tkrtspec .and. code .le. 3) then
+               if( tkrtspec ) then
                   call kwhist2( rtspec1(code, i), sr, 
      *              sngl( aTrack.t ), 1.0)
                   call kwhist2( rtspec2(code, i), sr, 
      *              sngl( aTrack.t ), 1.0)
                endif
 
-               if(tkretspec .and. code .le. 3) then
+               if(tkretspec ) then
                   call kwhist3( retspec1(code, i), sr,  Ek, 
      *                 sngl( aTrack.t ), 1.0)
                   call kwhist3( retspec2(code, i), sr,  Ek, 
      *                 sngl( aTrack.t ), 1.0)
                endif
 
-               if( tkrezspec .and. code .le. 3 ) then
+               if( tkrezspec ) then
                   call kwhist3( rezspec(code,i), sr, Ek, 
      *              sngl(wz),  1.0 ) 
                endif
 
-               if( tkrzfspec .and. code .le. 3) then
+               if( tkrzfspec ) then
                   call kwhist3( rzfspec(code, i),  sr, 
      *                 sngl(wz), f, 1.0)
                endif
 
-               if( tkrefspec .and. code .le. 3) then
+               if( tkrefspec ) then
                   call kwhist3( refspec(code, i),  sr, 
      *                 Ek, f, 1.0)
                endif
@@ -800,17 +838,26 @@ c     **************
                call kwhistp( lossrspec(j, i), fno)
             enddo
          enddo
-       
 
-c         do i = 1, ansites
-c            call kwhists( lossrspec2(i), 0. )
-c            call kwhistev(lossrspec2d3(j,i), EventNo)
-c            call kwhistid( lossrspec2(i), evid(i)//' a'//' dEr2')
-c            call kwhistp( lossrspec2(i), fno)
-c         enddo
       endif
  120  continue
       
+      if(tkarspec) then
+         do j = 1, 3
+            do i = 1, ansites
+               call kwhists2( arspec(j, i), 0. )
+               call kwhistev2( arspec(j,i), EventNo)
+               call kwhistid2( arspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(arspec(j, i),  dirstr)
+               call kwhistp2( arspec(j, i),  fno)
+            enddo
+         enddo
+      endif
+      
       if(tkrespec) then
          do j = 1, 3
             do i = 1, ansites
