@@ -119,7 +119,11 @@ c          lab sin^2 of gamma2
        else
           cos2=sqrt(1.d0 - sint2)
        endif
-       if(eg2 .lt. masele) then
+c
+c           pcos = gcE*(bc + cos*)
+c           cos*= -u so cos< 0 if bc+cos* < 0  
+c
+       if(bc-u .lt. 0.) then
          cos2=-cos2
        endif
        end
