@@ -68,14 +68,13 @@ c         endif
 c
          if(aPtcl.code .eq. kelec) then
             charge = aPtcl.charge
-            call cdedxElec(erg, charge, dedt)  ! in GeV/(g/cm2)
+            call cdedxe(aPtcl, rhoin, dedt)  ! in GeV/(g/cm2)
             dedt = dedt / 10.                ! to GeV/(kg/m2)
-         elseif(erg .gt. aPtcl.mass*3) then
-            call cdedxatHE(aPtcl, rhoin, dedt)  ! in GeV/(kg/m2)
          else
-            call cdedx2atLE(erg, aPtcl.mass, dedt) ! in GeV/(g/cm2)
+            call cdedxNone(aPtcl, rhoin,  dedt) ! in GeV/(g/cm2)
             dedt = dedt / 10.                ! in GeV/(kg/m2)
          endif
+
          end
 
             
