@@ -18,6 +18,6 @@ c           gp x-section,   xs in mb
          call rndc(u)
          t=-log(u)*t
       else
-         t=1.e50
+         t=1.0d50
       endif
       end
