@@ -1,15 +1,15 @@
 #!/bin/sh 
 #  manipulate histograms
-source $COSMOSTOP/UserHook/DisPara/Smash/setupenv.sh $0
-source $COSMOSTOP/UserHook/DisPara/FleshHist/setupenv.sh $0
+source $COSMOSTOP/UserHook/DisParaForTA/Smash/setupenv.sh $0
+source $COSMOSTOP/UserHook/DisParaForTA/FleshHist/setupenv.sh $0
 
 
 echo " execid =  $EXECID"
 echo " fleshdir= $FLESHDIR"
 
 ###  reset next if above  is ng.
-#EXECID=p3x15cos1.0
-#export EXECID
+#EXECID=p18cos0.9
+export EXECID
 
 
 source ./setupManipHistEnv.sh
