@@ -1,9 +1,11 @@
 #include "../cmain.f"
 #include "chookHybAS.f"
 #include "../ctemplCeren.f"
-c     NOTE:  chookEInt and chookGInt should not be used as of 
-c            version uv0.64001    
-c
+      subroutine time(xxx)
+      integer xxx
+      xxx = 1
+      end
+      
 c  *************************************** hook for Beginning of a Run
 c  * At this moment, all (system-level) initialization for this run
 c  * has been ended.  After this routine is executed, the system goes into the
@@ -13,12 +15,12 @@ c  *
       implicit none
 #include "Zmanagerp.h"
 
+ 
 c         If you feel writing the parameters on stderr is
 c         a bother, comment out the next or
 c         use other device than ErrorOut.
 c         Also you may comment out all output routines below.
 
-c
 c            namelist output
       call cwriteParam(ErrorOut, 0)
 c            primary information
@@ -35,34 +37,22 @@ c     *  After this is executed, event generation starts.
 c     *
       subroutine chookBgEvent
       implicit none
-#include "Zprivate.h"
 #include "Ztrack.h"
-#include "Ztrackv.h"
 #include "Zobs.h"
-#include "Zobsp.h"
 #include "Zobsv.h"
+      include "Zprivate.h"
 
-#include "Zcode.h"
-#include "Zmass.h"
-
-      record /track/inci, pj
-      record /coord/angle
-
-      integer i
-c      write(*, *) ' bigin event generation'
-      do i = 1, NoOfSites
-         neg(1,i) = 0
-         neg(2,i) = 0
-      enddo
-
-
-      call cqIncident(inci, angle)
-      write(0,*) ' incident=',inci.p.code,' e=',inci.p.fm.p(4)
+      integer i, j
+      sume = 0
+      sumepi0 = 0
+      nc = 0
+      ncpi0= 0 
+      call cqUhookr(1, cut)
       end
-
+  
 
 c     ************************************ hook for observation
-c     *  One particel information is brought here by the system.
+c     *  One particle information is brought here by the system.
 c     *  All information of the particle is in aTrack
 c     *
       subroutine chookObs(aTrack, id)
@@ -73,9 +63,10 @@ c     In some cases it is essential to put it in sigle (say,
 c     for gnuplot).
 c 
       implicit none
-#include "Zcode.h"
 #include "Ztrack.h"
-#include "Zprivate.h"
+#include  "Zcode.h"
+      include "Zprivate.h"
+
       integer id  ! input.  1 ==> aTrack is going out from
 c                                 outer boundery.
 c                           2 ==> reached at an observation level
@@ -85,45 +76,40 @@ c
 c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
-      if(id .eq. 2  ) then
-         neg(aTrack.p.code, aTrack.where)=
-     *          neg(aTrack.p.code, aTrack.where) + 1
-
+c      if(id .eq. 2 .and.  aTrack.vec.coszenith .gt. 0 ) then
+c         if(aTrack.p.code .le. 3) then
+c            nc(aTrack.p.code, aTrack.where) = 
+c     *        nc(aTrack.p.code, aTrack.where) +1
+c         endif
+c      endif
 c            output typical quantities.
-c        write(*, *)  
+c        write(*, '(3i5, ) 
 c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
 c     *  aTrack.p.code,    !  ptcl code.  integer*2.
-c     *  aTrack.p.subcode,
 c     *  aTrack.p.charge,  !  charge,  integer*2 
-c     *  sngl(aTrack.t) !  relateive arrival time in nsec (NOT sec).
+c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
 c                        !  if TimeStructure is F, nonsense.
-c     *  sngl(aTrack.p.fm.p(4)-aTrack.p.mass)  ! total energy in GeV.
+c     *  sngl(aTrack.p.fm.p(4))  ! total energy in GeV.
 c     *  sngl(aTrack.pos.xyz.r(1)), sngl(aTrack.pos.xyz.r(2)), !  x, y in m
 c     *  sngl(aTrack.vec.w.r(1)),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.r(2)),  ! direc. cos.y
 c     *  sngl(aTrack.vec.w.r(3)),  ! direc. cos.z
-c     *  sngl(aTrack.vec.coszenith), ! cos of zenith angle
-c     *  aTrack.wgt         ! weight of the particle (may not be 1. if
-                                 ! ThinSampling =T)
-c         if(aTrack.p.code .eq. 2) then
-c            neg(aTrack.where) = nebyc(aTrack.where) + aTrack.wgt
-c         endif
-       endif
+c     *  sngl(aTrack.vec.coszenith) ! cos of zenith angle
+c      endif
 c         you may need in some case other information such as
 c       aTrack.p.subcode   ! sub code of the particle integer*2
 c       aTrack.p.mass      ! mass 
-
-
+c       aTrack.wgt         ! weight of the particle (may not be 1. if
+                           ! ThinSampling =T)
 c       aTrack.p.fm.p(1)      ! momentum x component.  Note. Momentum is
 c                            given in the  Earth xyz system.
+
 c       aTrack.p.fm.p(2)      !          y
 c       aTrack.p.fm.p(3)      !          z
-c               To convert the momentum into the observational
-c               coordinate system,  you may call
-c       call cresetMom(aTrack)
+
       end
 
-c    *********************************** hook for end of 1 vent
+c    *********************************** hook for end of 1 event
 c    * At this moment, 1 event generation has been ended.
 c    *
       subroutine chookEnEvent
@@ -134,28 +120,23 @@ c    *
 #include "Zobs.h"
 #include "Zobsp.h"
 #include "Zobsv.h"
-#include "Zmanagerp.h"
-#include "Zprivate.h"
+      include "Zprivate.h"
 
-      integer i
+      integer i, j
+c      do i = 1, NoOfSites
+c         do j = 1, 3
+c            write(*, *) i, j, nc(j, i)
+c         enddo
+c      enddo
       if(ObserveAS) then
 c                   electron size in B approx.
-         do i=1, NoOfASSites
-c            write(*, '(f9.1,g15.3,f8.3,g15.2)' )
-c     *      sngl(ASDepthList(i)*0.1),
-c     *      sngl( ASObsSites(i).esize),sngl(ASObsSites(i).age),
-c     *          nebyc(i)
+         write(*,*) 'e ', sngl(sume), nc, sngl(sumepi0), ncpi0
+         do i = 1, NoOfASSites
+            write(*, *) 's ',  sngl( ASDepthList(i)*0.1 ),
+     *       sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age)
          enddo
       endif
-      do i = 1, NoOfSites
-         write(*,*) i, neg(1,i), neg(2,i)
-      enddo
-      write(*,*) ' Zf =', Zfirst.pos.depth
-c        ************ if you want to flesh this event later
-c        you may keep the random no. seed  by the following
-      if(Job .eq. 'skeleton') then
-         call cwriteSeed        !  SeedFile
-      endif
+      write(*,*)
       end
 
 
@@ -163,11 +144,17 @@ c     ********************************* hook for end of a run
 c     *  all events have been created or time lacks
 c     *
       subroutine chookEnRun
+
       implicit none
-      call  cprintStatus   ! if don't like,  comment out
+#include "Ztrack.h"
+#include "Ztrackp.h"
+
+
+
+
       end
 c     ********************************* hook for trace
-c     *  This is called only when trace > 100
+c     *  This is called only when trace > 60
 c     *  User should manage the trace information here.
 c     *  If you use this, you may need some output for trace
 c     *  at the beginning of 1 event generatio and at the end of  1 event
@@ -183,10 +170,10 @@ c     *
 #include  "Zobs.h"
 #include  "Zobsv.h"
 
-       real*4 h1,  h2
+      real*4 h1,  h2
 c
 c    Every time a particle is moved in the atmosphere, this routine is called,
-c    if trace > 100
+c    if trace > 60. 
 c         For a one track segment,
 c     TrackBefMove  has  track information at the beginning of the segment.
 c     MoveTrack    has   track information at the end of the segment.
@@ -231,7 +218,7 @@ c        default setting
       never = 1
 c
 c        IntInfArray(ProcessNo).process will have one of
-c       'brems', 'mscat', 'bscat'  'anihi' or 'mbrem'
+c       'brems', 'mscat', 'bscat',or  'anihi'
 c
       end
 
@@ -259,7 +246,7 @@ c
 c        default setting
       never = 1
 c         IntInfArray(ProcessNo).process will have one of
-c        'pair', 'comp', 'photoe' 'photop' 'mpair'
+c        'pair', 'comp', 'photoe' or 'photop'
 c       
       end
 
@@ -271,11 +258,11 @@ c
 
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
-#include  "Ztrackp.h"
-      
+#include  "Zcode.h"
+      include "Zprivate.h"
       integer never   ! input & output
-
       integer i
+
 c         don't make never = 1, if you want to get
 c         information after a non-e-g particle  made interaction
 c         if this is made non zero, this routine will never be called.
@@ -285,14 +272,32 @@ c   Pwork contains produced particles.
 c   Nproduced has the number of particles in Pwork
 c   IntInfArray(ProcessNo) contains the type of interaction
 c
-c        default setting
-c      never = 1
-
-      never = 1
+c        default setting is 1
+      never = 0
 
 c
 c        IntInfArray(ProcessNo).process  will have
-c             'col' or 'decay'
+c             'coll' or 'decay'
+      if(cut .lt. 1.) then
+         if( IntInfArray(ProcessNo).process   .eq. 'coll' ) then
+            do i = 1, Nproduced
+c              for pions, kaons put E=mass if X > cut (for cut>0)
+               if( Pwork(i).code .lt. knuc ) then
+                  if( Pwork(i).fm.p(4) / MovedTrack.p.fm.p(4)
+     *                 .gt. cut) then
+                     sume = sume +  Pwork(i).fm.p(4)
+                     nc = nc +1
+                     if( Pwork(i).code .eq. kpion .and.
+     *                   Pwork(i).charge .eq. 0 ) then
+                        sumepi0 = sumepi0 + Pwork(i).fm.p(4)
+                        ncpi0= ncpi0 + 1
+                     endif
+                     Pwork(i).fm.p(4) = Pwork(i).mass*1.1
+                  endif
+               endif
+            enddo
+         endif
+      endif
       end
 
       
