@@ -15,10 +15,12 @@ c       ***************************************** stave  cont info
 
       PrevEventNo = EventNo    ! current event no.
       call rnd1s(InitRN)  !  current seed.
-      call copenNLfw(TempDev, ContFile, icon)
+      if(ContFile .ne. ' ' ) then
+         call copenNLfw(TempDev, ContFile, icon)
 c      open(TempDev, file=ContFile, form='formatted')
-      call cwriteParam(TempDev, 1)
-      close(TempDev)
+         call cwriteParam(TempDev, 1)
+         close(TempDev)
+      endif
       end
 c       ***************************************** print final status
       subroutine cprintStatus
