@@ -143,7 +143,7 @@ c
       record /track/ aTrack  
       integer i, icon
       
-      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
+c      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
 
       aTrack = iTrack
 
@@ -162,7 +162,8 @@ c               reset direction cos and related stuffs
          call cresetDirec(aTrack)
 
 
-         if(needThin) then
+c         if(needThin) then
+         if(ThinSampling) then
             call csetThinwgt(iTrack, aTrack,  icon)
          else
             icon = 0
@@ -282,7 +283,7 @@ c          1 dimensional case.
       
       record /track/ aTrack 
 
-      needThin =ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
+c      needThin =ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
 
       aTrack = iTrack
 
@@ -313,7 +314,8 @@ c            call cresetMom(aTrack)  which is
 
             call cgetZenith(aTrack, aTrack.vec.coszenith)
 
-            if(needThin) then
+c            if(needThin) then
+            if(ThinSampling) then
                call csetThinwgt(iTrack, aTrack, icon)
             else
                icon = 0
@@ -387,18 +389,32 @@ c     ***************************
       record /track/ aTrack  ! input/output.    particle
       integer icon           ! output.  0 if this is not tobe discarded
                              !          1 if this is to be discarded
-      real*8 iwgt, u
+      real*8 u, p 
 
-
-
-      iwgt = aTrack.p.fm.p(4)/iTrack.p.fm.p(4) ! inverse weight
-
-      call rndc(u)
-      if(u .gt. iwgt) then
-         icon =1                !  discard this ptcl
+      if(iTrack.p.fm.p(4) .gt. Ethin) then
+         if(aTrack.p.fm.p(4) .gt. Ethin) then
+            p = 1.
+            icon = 0
+         else
+            p = aTrack.p.fm.p(4)/Ethin
+            call rndc(u)
+            if(u .lt. p)  then
+               icon = 0
+            else
+               icon = 1
+            endif
+         endif
       else
-         aTrack.wgt = iTrack.wgt /iwgt
-         icon = 0
+         p = aTrack.p.fm.p(4)/iTrack.p.fm.p(4) 
+         call rndc(u)
+         if(u .lt. p ) then
+            icon = 0
+         else
+            icon = 1
+         endif
+      endif
+      if(icon .eq. 0) then
+         aTrack.wgt = iTrack.wgt / p
       endif
       end
 
