@@ -51,5 +51,34 @@ c         initialize stack.
 #include  "Zstackv.h"
       Stack_pos = 0
       end
+      subroutine csortStack
+c        sort stack dscending order 
+      implicit none
+#include  "Zmaxdef.h"
+#include  "Ztrack.h"
+#include  "Zstackv.h"
+      real*8 erg(Max_stack_size)
+      record /track/ sorted(Max_stack_size)
+      integer  idx(Max_stack_size)
+      
+      integer i, j, k
+      record /track/ temp
+      do  i = 1,  Stack_pos
+         erg(i) = Stack(i).p.fm.p(4)
+      enddo
+      
+      call kqsortd(erg, idx, Stack_pos)
+      call ksortinv(idx, Stack_pos)
+      
+      do i = 1, Stack_pos
+         sorted(i) = Stack(idx(i))
+      enddo
+
+      do i = 1, Stack_pos
+         Stack(i) = sorted(i)
+      enddo
+      end
+
+      
 
       
